**To deregister a directory**

The following ``deregister-workspace-directory`` example deregisters the specified directory. ::

    aws workspaces deregister-workspace-directory \
        --directory-id d-926722edaf

This command produces no output.

For more information, see `Register a directory with WorkSpaces <https://docs.aws.amazon.com/workspaces/latest/adminguide/register-deregister-directory.html>`__ in the *Amazon WorkSpaces Administration Guide*.
